@@ -301,7 +301,7 @@ class Chat(base.TelegramObject):
                                                    can_send_other_messages=can_send_other_messages,
                                                    can_add_web_page_previews=can_add_web_page_previews)
 
-    async def promote(self, 
+    async def promote(self,
                       user_id: base.Integer,
                       is_anonymous: typing.Optional[base.Boolean] = None,
                       can_change_info: typing.Optional[base.Boolean] = None,
@@ -321,36 +321,36 @@ class Chat(base.TelegramObject):
 
         :param user_id: Unique identifier of the target user
         :type user_id: :obj:`base.Integer`
-        
+
         :param is_anonymous: Pass True, if the administrator's presence in the chat is hidden
         :type is_anonymous: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_change_info: Pass True, if the administrator can change chat title, photo and other settings
         :type can_change_info: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_post_messages: Pass True, if the administrator can create channel posts, channels only
         :type can_post_messages: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_edit_messages: Pass True, if the administrator can edit messages of other users, channels only
         :type can_edit_messages: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_delete_messages: Pass True, if the administrator can delete messages of other users
         :type can_delete_messages: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_invite_users: Pass True, if the administrator can invite new users to the chat
         :type can_invite_users: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_restrict_members: Pass True, if the administrator can restrict, ban or unban chat members
         :type can_restrict_members: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_pin_messages: Pass True, if the administrator can pin messages, supergroups only
         :type can_pin_messages: :obj:`typing.Optional[base.Boolean]`
-        
+
         :param can_promote_members: Pass True, if the administrator can add new administrators
             with a subset of his own privileges or demote administrators that he has promoted,
             directly or indirectly (promoted by administrators that were appointed by him)
         :type can_promote_members: :obj:`typing.Optional[base.Boolean]`
-        
+
         :return: Returns True on success.
         :rtype: :obj:`base.Boolean`
         """
@@ -484,16 +484,20 @@ class Chat(base.TelegramObject):
         """
         return await self.bot.get_chat_administrators(self.id)
 
-    async def get_members_count(self) -> base.Integer:
+    async def get_member_count(self) -> base.Integer:
         """
         Use this method to get the number of members in a chat.
 
-        Source: https://core.telegram.org/bots/api#getchatmemberscount
+        Source: https://core.telegram.org/bots/api#getchatmembercount
 
         :return: Returns Int on success.
         :rtype: :obj:`base.Integer`
         """
-        return await self.bot.get_chat_members_count(self.id)
+        return await self.bot.get_chat_member_count(self.id)
+
+    async def get_members_count(self) -> base.Integer:
+        """Renamed to get_member_count."""
+        return await self.get_member_count(self.id)
 
     async def get_member(self, user_id: base.Integer) -> ChatMember:
         """
